wasd library
Classes
- DefinedRuntimeFunction
- GcBrOnCastImmediate
- GcRefTypeImmediate
- HostRuntimeFunction
- Instruction
- LegacyCatchClause
- LegacyCatchKind
- MemArg
- Opcodes
- PredecodedFunction
- RuntimeFunction
- RuntimeGlobal
- TryTableCatchClause
- TryTableCatchKind
- WasiDirectoryEntry
- WasiDirectoryListingFileSystem
- WasiFileDescriptor
- WasiFileSystem
- WasiInMemoryFileSystem
- WasiMutablePathFileSystem
- WasiPathLinkFileSystem
- WasiPathMetadataFileSystem
- WasiPathStat
- WasiPathTimesFileSystem
- WasiPreview1
- WasiRunner
- WasiSockAcceptResult
- WasiSocketTransport
- WasiSockRecvResult
- WasiSockSendResult
- WasmCanonicalAbi
- WasmCanonicalAbiAllocator
- WasmCanonicalAbiListType
- WasmCanonicalAbiPrimitiveType
- WasmCanonicalAbiRecordField
- WasmCanonicalAbiRecordType
- WasmCanonicalAbiResourceHandle
- WasmCanonicalAbiResourceType
- WasmCanonicalAbiResultType
- WasmCanonicalAbiResultValue
- WasmCanonicalAbiType
- WasmCanonicalAbiVariantCase
- WasmCanonicalAbiVariantType
- WasmCanonicalAbiVariantValue
- WasmCodeBody
- WasmComponent
- Minimal component binary decoder.
- WasmComponentCoreExportAlias
- Component-level exported core alias.
- WasmComponentCoreInstance
-
Decoded core instance declaration from component section
0x02. - WasmComponentCoreInstanceAlias
-
Alias binding for a core instance index, decoded from section
0x05. - WasmComponentCoreInstanceArgument
-
Decoded core instance instantiation argument from component section
0x02. - WasmComponentCoreInstanceExport
-
Decoded core instance declaration from component section
0x02. - WasmComponentImportRequirement
-
Component-level import requirement decoded from section
0x04. - WasmComponentInstance
- Component-level runtime that instantiates embedded core modules.
- WasmComponentSection
- Decoded component section payload.
- WasmComponentTypeBinding
-
Type binding edge decoded from section
0x07. - WasmComponentTypeDeclaration
-
Component type declaration decoded from section
0x06. - WasmDataSegment
- WasmElementSegment
- WasmExport
- WasmExportKind
- WasmF32Bits
- WasmF64Bits
- WasmFeatureSet
- WasmFunctionType
- WasmGlobalDef
- WasmGlobalType
- WasmImport
- WasmImportKind
- WasmImports
- WasmInstance
- WasmLimits
- WasmLocalDecl
- WasmMemory
- WasmMemoryType
- WasmModule
- WasmPredecoder
- WasmTable
- WasmTableType
- WasmTagImport
- WasmTagType
- WasmValidator
- WasmValue
- WasmVm
Enums
Extensions
Constants
- wasmAddressSpaceBytes → const int
- wasmMaxPages → const int
- wasmPageSize → const int
Typedefs
- WasiReadSource = Uint8List Function(int maxBytes)
- WasiSockAcceptHandler = WasiSockAcceptResult Function({required WasiSockAllocateFd allocateFd, required int fd, required int flags})
- WasiSockAllocateFd = int Function()
- WasiSockCloseHandler = int Function({required int fd})
- WasiSockContainsFdHandler = bool Function({required int fd})
- WasiSockRecvHandler = WasiSockRecvResult Function({required int fd, required int flags, required int maxBytes})
- WasiSockSendHandler = WasiSockSendResult Function({required Uint8List data, required int fd, required int flags})
- WasiSockShutdownHandler = int Function({required int fd, required int how})
- WasiWriteSink = void Function(Uint8List bytes)
-
WasmAsyncHostFunction
= FutureOr<
Object?> Function(List<Object?> args) -
WasmHostFunction
= Object? Function(List<
Object?> args)