DefinedRuntimeFunction class final

Inheritance

Constructors

DefinedRuntimeFunction({required WasmFunctionType type, required List<WasmValueType> localTypes, required List<Instruction> instructions})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
instructions List<Instruction>
final
isHost bool
no setteroverride
localTypes List<WasmValueType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type WasmFunctionType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited