Exception class abstract interface

Represents a WebAssembly exception instance.

Constructors

Exception(Tag tag, List<Object?> payload, [ExceptionOptions? options])
Creates an exception with tag, ordered payload values, and options.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArg(Tag tag, int index) Object?
Returns payload value at index interpreted for tag.
isTag(Tag tag) bool
Returns whether this exception matches tag (maps to JS is(tag)).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited