Int32 class final

32-bit integer value.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
kind ValueKind<Int32, int>
Kind marker of this concrete value.
no setteroverride
ref int
Wrapped raw runtime reference/value.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited