MemoryDescriptor class

Describes limits and behavior of a WebAssembly linear memory.

Constructors

MemoryDescriptor({required int initial, int? maximum, bool? shared})
Creates a memory descriptor.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initial int
Initial memory size in WebAssembly pages (64 KiB per page).
final
maximum int?
Optional maximum memory size in pages.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shared bool?
Whether this memory is shared between agents/threads.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited