ModuleImportDescriptor class

Module import descriptor metadata.

Constructors

ModuleImportDescriptor({required ImportExportKind<Object, ExportValue<Object, dynamic>> kind, required String module, required String name})
Creates a module import descriptor.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind ImportExportKind<Object, ExportValue<Object, dynamic>>
Kind of the imported value.
final
module String
Source module name.
final
name String
Import name in the source module.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited