Table<T extends Value<T, V>, V extends Object?> class abstract interface

Minimal table interface.

Constructors

Table(TableDescriptor<T, V> descriptor, [V? value])
Creates a table from descriptor and optional initial value.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Current table length.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(int index) → V?
Returns the element at index, or null for an empty slot.
grow(int delta, [V? value]) int
Grows table length by delta, optionally using fill value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(int index, V? value) → void
Writes value into the element slot at index.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited