Vector128 class final
128-bit vector value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kind
→ ValueKind<
Vector128, ByteData> -
Kind marker of this concrete value.
no setteroverride
- ref → ByteData
-
Wrapped raw runtime reference/value.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited