WASIComponentAsyncCopyResult class final

Result of a canonical async stream memory copy operation.

Constructors

WASIComponentAsyncCopyResult.cancelled([int copiedElements = 0])
Cancelled copy result for copiedElements.
factory
WASIComponentAsyncCopyResult.completed(int copiedElements)
Completed copy result for copiedElements.
factory
WASIComponentAsyncCopyResult.dropped([int copiedElements = 0])
Dropped copy result for copiedElements.
factory

Properties

copiedElements int
Number of elements copied before status was observed.
final
hashCode int
The hash code for this object.
no setterinherited
packedResult int
Canonical packed result: status in low bits, element count above bit 4.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status WASIComponentAsyncCopyStatus
Copy status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited