WASIComponentAsyncEndpointHandles class final

Pair of canonical readable and writable endpoint handles.

Constructors

WASIComponentAsyncEndpointHandles({required int readable, required int writable})
Creates an endpoint handle pair.
WASIComponentAsyncEndpointHandles.unpack(int packed)
Unpacks the canonical i64 handle pair used by stream/future.new.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
packed int
Canonical signed i64 with readable in low bits and writable in high bits.
no setter
readable int
Readable endpoint handle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writable int
Writable endpoint handle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited