WASIComponentCanonicalAsyncOperation class final

Executable form of a canonical stream/future operation.

Properties

componentTypeIndex int?
Component type index the operation targets.
final
hashCode int
The hash code for this object.
no setterinherited
isAsync bool
Whether this canonical operation was decoded with the async flag.
final
kind WasmComponentCanonicalKind
Canonical async operation kind.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringEncoding WASIComponentCanonicalStringEncoding
Canonical string encoding configured by decoded operation options.
final

Methods

backpressureDecrement() int
Executes backpressure.dec.
backpressureIncrement() int
Executes backpressure.inc.
backpressureSet(bool active) int
Executes backpressure.set.
futureCancelRead(Object? readable) → void
Executes future.cancel-read.
futureCancelReadHandle(int readable) int
Executes future.cancel-read with a readable endpoint handle.
futureCancelReadHandleWhenReady(int readable) Future<int>
Executes future.cancel-read with a readable endpoint handle, waiting for the copy event when the canonical operation is synchronous.
futureCancelWrite(Object? writable) → void
Executes future.cancel-write.
futureCancelWriteHandle(int writable) int
Executes future.cancel-write with a writable endpoint handle.
futureCancelWriteHandleWhenReady(int writable) Future<int>
Executes future.cancel-write with a writable endpoint handle, waiting for the copy event when the canonical operation is synchronous.
futureDropReadable(Object? readable) → void
Executes future.drop-readable.
futureDropReadableHandle(int readable) → void
Executes future.drop-readable with a readable endpoint handle.
futureDropWritable(Object? writable) → void
Executes future.drop-writable.
futureDropWritableHandle(int writable) → void
Executes future.drop-writable with a writable endpoint handle.
futureNew() Object
Executes future.new.
futureNewHandles() WASIComponentAsyncEndpointHandles
Executes future.new and returns endpoint handles.
futureNewPackedHandles() int
Executes future.new and returns the canonical packed handle pair.
futureRead(Object? readable) Object?
Executes future.read.
futureReadHandle(int readable) Object?
Executes future.read with a readable endpoint handle.
futureReadHandleToMemory(int readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) WASIComponentAsyncCopyResult
Executes handle-backed future.read into memory.
futureReadHandleToMemoryEvent(int readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) int
Starts handle-backed future.read into memory and publishes an event.
futureReadHandleToMemoryWhenReady(int readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) Future<WASIComponentAsyncCopyResult>
Executes handle-backed future.read into memory when ready.
futureReadHandleWhenReady(int readable) Future<Object?>
Executes future.read with a readable endpoint handle and waits if pending.
futureReadToMemory(Object? readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) WASIComponentAsyncCopyResult
Executes future.read and writes a value to memory.
futureReadWhenReady(Object? readable) Future<Object?>
Executes future.read and waits if the future is still pending.
futureWrite(Object? writable, Object? value) → void
Executes future.write.
futureWriteFromMemory(Object? writable, Memory memory, int pointer) WASIComponentAsyncCopyResult
Executes future.write by reading a value from memory.
futureWriteHandle(int writable, Object? value) → void
Executes future.write with a writable endpoint handle.
futureWriteHandleFromMemory(int writable, Memory memory, int pointer) WASIComponentAsyncCopyResult
Executes handle-backed future.write from memory.
futureWriteHandleFromMemoryEvent(int writable, Memory memory, int pointer) int
Starts handle-backed future.write from memory and publishes an event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamCancelRead(Object? readable) → void
Executes stream.cancel-read.
streamCancelReadHandle(int readable) int
Executes stream.cancel-read with a readable endpoint handle.
streamCancelReadHandleWhenReady(int readable) Future<int>
Executes stream.cancel-read with a readable endpoint handle, waiting for the copy event when the canonical operation is synchronous.
streamCancelWrite(Object? writable) → void
Executes stream.cancel-write.
streamCancelWriteHandle(int writable) int
Executes stream.cancel-write with a writable endpoint handle.
streamCancelWriteHandleWhenReady(int writable) Future<int>
Executes stream.cancel-write with a writable endpoint handle, waiting for the copy event when the canonical operation is synchronous.
streamDropReadable(Object? readable) → void
Executes stream.drop-readable.
streamDropReadableHandle(int readable) → void
Executes stream.drop-readable with a readable endpoint handle.
streamDropWritable(Object? writable) → void
Executes stream.drop-writable.
streamDropWritableHandle(int writable) → void
Executes stream.drop-writable with a writable endpoint handle.
streamNew() Object
Executes stream.new.
streamNewHandles() WASIComponentAsyncEndpointHandles
Executes stream.new and returns endpoint handles.
streamNewPackedHandles() int
Executes stream.new and returns the canonical packed handle pair.
streamRead(Object? readable, int maxElements) List<Object?>
Executes stream.read.
streamReadHandle(int readable, int maxElements) List<Object?>
Executes stream.read with a readable endpoint handle.
streamReadHandleToMemory(int readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) WASIComponentAsyncCopyResult
Executes handle-backed stream.read into memory elements.
streamReadHandleToMemoryEvent(int readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) int
Starts handle-backed stream.read into memory and publishes an event.
streamReadHandleToMemoryWhenAvailable(int readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) Future<WASIComponentAsyncCopyResult>
Executes handle-backed stream.read into memory when values exist.
streamReadHandleWhenAvailable(int readable, int maxElements) Future<List<Object?>>
Executes stream.read with a readable endpoint handle and waits if the stream has no queued values.
streamReadToMemory(Object? readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) WASIComponentAsyncCopyResult
Executes stream.read and writes elements to memory.
streamReadWhenAvailable(Object? readable, int maxElements) Future<List<Object?>>
Executes stream.read and waits if the stream has no queued values.
streamWrite(Object? writable, Object? values) int
Executes stream.write.
streamWriteFromMemory(Object? writable, Memory memory, int pointer, int elementCount) WASIComponentAsyncCopyResult
Executes stream.write by reading elements from memory.
streamWriteHandle(int writable, Object? values) int
Executes stream.write with a writable endpoint handle.
streamWriteHandleFromMemory(int writable, Memory memory, int pointer, int elementCount) WASIComponentAsyncCopyResult
Executes handle-backed stream.write from memory elements.
streamWriteHandleFromMemoryEvent(int writable, Memory memory, int pointer, int elementCount) int
Starts handle-backed stream.write from memory and publishes an event.
streamWriteHandleFromMemoryWhenAvailable(int writable, Memory memory, int pointer, int elementCount) Future<WASIComponentAsyncCopyResult>
Executes handle-backed stream.write from memory when capacity exists.
streamWriteHandleWhenAvailable(int writable, Object? values) Future<int>
Executes stream.write with a writable endpoint handle and waits if the stream has no write capacity.
streamWriteWhenAvailable(Object? writable, Object? values) Future<int>
Executes stream.write and waits if the stream has no write capacity.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited