streamCancelReadHandleWhenReady method

Future<int> streamCancelReadHandleWhenReady(
  1. int readable
)

Executes stream.cancel-read with a readable endpoint handle, waiting for the copy event when the canonical operation is synchronous.

Implementation

Future<int> streamCancelReadHandleWhenReady(int readable) {
  _requireKind(WasmComponentCanonicalKind.streamCancelRead);
  return _requireValueType().streamCancelReadHandleWhenReady(
    readable,
    isAsync: isAsync,
  );
}