WASIComponentCanonicalAsyncProgram class final

Executable stream/future-only canonical program for a decoded component.

Constructors

WASIComponentCanonicalAsyncProgram({required List<WASIComponentCanonicalAsyncOperation> operations})
Creates a canonical async program from ordered operations.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<WASIComponentCanonicalAsyncOperation>
Stream/future operations in component canonical definition order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(int canonicalIndex, List<Object?> args) Object?
Invokes the canonical async operation at canonicalIndex.
invokeAsync(int canonicalIndex, List<Object?> args) Future<Object?>
Invokes a canonical async operation and waits for pending future reads.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited