WASIComponentCanonicalHostUnsupportedDefinition class final

One unsupported canonical definition found during host capability preflight.

Constructors

WASIComponentCanonicalHostUnsupportedDefinition({required int canonicalIndex, required WasmComponentCanonicalDefinition definition, required String reason})
Creates an unsupported-definition report.
const

Properties

canonicalIndex int
Canonical definition index in the decoded component.
final
definition WasmComponentCanonicalDefinition
Decoded canonical definition that cannot be bound.
final
hashCode int
The hash code for this object.
no setterinherited
kind WasmComponentCanonicalKind
Canonical kind that cannot be bound.
no setter
reason String
Why this host cannot bind definition.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited