WASIComponentCanonicalOperation class final

Bound canonical operation.

Properties

hashCode int
The hash code for this object.
no setterinherited
kind WasmComponentCanonicalKind
Canonical operation kind.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(List<Object?> args) Object?
Invokes this canonical operation.
invokeAsync(List<Object?> args) Future<Object?>
Invokes this canonical operation and waits when supported.
invokeFlat(List<Object?> args, {Memory? memory, WASIComponentCanonicalRealloc? realloc}) List<Object?>
Invokes this canonical operation through flat Canonical ABI scalars.
invokeFlatAsync(List<Object?> args, {Memory? memory, WASIComponentCanonicalRealloc? realloc}) Future<List<Object?>>
Invokes this canonical operation asynchronously through flat Canonical ABI scalars.
invokeWithMemory(Memory memory, List<Object?> args, {int? resultPointer, WASIComponentCanonicalRealloc? realloc}) Object?
Invokes this canonical operation with memory.
invokeWithMemoryAsync(Memory memory, List<Object?> args, {int? resultPointer, WASIComponentCanonicalRealloc? realloc}) Future<Object?>
Invokes this canonical operation with memory and waits when supported.
invokeWithMemoryEvent(Memory memory, List<Object?> args, {int? resultPointer, WASIComponentCanonicalRealloc? realloc}) Object?
Starts this canonical operation's waitable event path with memory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited