WASIComponentCanonicalResourceProgram class final

Executable resource-only canonical program for a decoded component.

Constructors

WASIComponentCanonicalResourceProgram({required List<WASIComponentCanonicalResourceOperation> operations})
Creates a canonical resource program from ordered operations.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<WASIComponentCanonicalResourceOperation>
Resource operations in component canonical definition order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(int canonicalIndex, List<Object?> args) Object?
Invokes the canonical resource operation at canonicalIndex.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited