WASIComponentCanonicalSubtaskProgram class final

Executable subtask canonical program for a decoded component.

Constructors

WASIComponentCanonicalSubtaskProgram({required List<WASIComponentCanonicalSubtaskOperation> operations})
Creates a canonical subtask program from ordered operations.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<WASIComponentCanonicalSubtaskOperation>
Subtask operations in component canonical definition order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(int canonicalIndex, List<Object?> args) Object?
Invokes a subtask operation.
invokeAsync(int canonicalIndex, List<Object?> args) Future<Object?>
Invokes a subtask operation and waits for non-async cancellation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited