WASIComponentCanonicalWaitableProgram class final

Executable waitable-set canonical program for a decoded component.

Constructors

WASIComponentCanonicalWaitableProgram({required List<WASIComponentCanonicalWaitableOperation> operations})
Creates a canonical waitable program from ordered operations.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<WASIComponentCanonicalWaitableOperation>
Waitable operations in component canonical definition order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

invoke(int canonicalIndex, List<Object?> args) Object?
Invokes a non-memory waitable operation.
invokeWithMemory(int canonicalIndex, Memory memory, List<Object?> args) Object?
Invokes a waitable operation that writes an event payload to memory.
invokeWithMemoryAsync(int canonicalIndex, Memory memory, List<Object?> args) Future<Object?>
Invokes a waitable operation and waits for an event when required.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited