WASIComponentContext class final

Thread-local storage for Component Model context.get/set.

Constructors

WASIComponentContext({String name = 'context', Iterable<int> initialSlots = const []})
Creates a context with zero-initialized i32 storage.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Debug label used in diagnostics.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(int index) int
Returns the i32 bit pattern stored in index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(int index, int value) → void
Stores the i32 bit pattern value in index.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited