WASIComponentHostBindingError class final

A component host binding gap found before mutating host state.

Constructors

WASIComponentHostBindingError({required int canonicalIndex, required WasmComponentCanonicalDefinition definition, required String reason})
Creates a component host binding error.
const

Properties

canonicalIndex int
Canonical definition index in the decoded component.
final
definition WasmComponentCanonicalDefinition
Canonical definition that this component host cannot currently wire.
final
hashCode int
The hash code for this object.
no setterinherited
kind WasmComponentCanonicalKind
Canonical kind that cannot be bound.
no setter
reason String
Why this component host cannot bind definition.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited