WASIComponentResourceBinding class final

A decoded component resource type that can be bound to a host type.

Constructors

WASIComponentResourceBinding({required int componentTypeIndex, required String name, required WASIComponentResourceRepresentation representation, required bool isAbstract})
Creates a resource binding descriptor.
const

Properties

componentTypeIndex int
Component type index of the resource.
final
hashCode int
The hash code for this object.
no setterinherited
isAbstract bool
Whether this resource was introduced without a concrete core representation.
final
name String
Stable debug name for this component resource.
final
representation WASIComponentResourceRepresentation
Core representation constraint decoded for this resource.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited