WASIComponentResourceRepresentation enum

Core representation type for a component resource.

Inheritance
Available extensions

Values

unconstrained → const WASIComponentResourceRepresentation

No decoded representation constraint is known.

const WASIComponentResourceRepresentation(null)
i32 → const WASIComponentResourceRepresentation

Core i32 representation.

const WASIComponentResourceRepresentation(0x7f)
i64 → const WASIComponentResourceRepresentation

Core i64 representation.

const WASIComponentResourceRepresentation(0x7e)
f32 → const WASIComponentResourceRepresentation

Core f32 representation.

const WASIComponentResourceRepresentation(0x7d)
f64 → const WASIComponentResourceRepresentation

Core f64 representation.

const WASIComponentResourceRepresentation(0x7c)

Properties

coreValueTypeCode int?
Component binary core value type code, when known.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCoreValueTypeCode(int? code) WASIComponentResourceRepresentation
Returns the representation for a component core value type code.

Constants

values → const List<WASIComponentResourceRepresentation>
A constant List of the values in this enum, in order of their declaration.