WASIComponentWitAdapterValueType class final

WIT value type supported by executable WIT adapters.

Constructors

WASIComponentWitAdapterValueType.enumeration({required String text, required List<String> labels})
Creates a named WIT enum adapter value type.
WASIComponentWitAdapterValueType.flags({required String text, required List<String> labels})
Creates a named WIT flags adapter value type.
WASIComponentWitAdapterValueType.future({required String text, required WASIComponentWitAdapterValueType element})
Creates a future<T> WIT adapter value type.
WASIComponentWitAdapterValueType.list({required String text, required WASIComponentWitAdapterValueType element})
Creates a list<T> WIT adapter value type.
WASIComponentWitAdapterValueType.option({required String text, required WASIComponentWitAdapterValueType element})
Creates an option<T> WIT adapter value type.
WASIComponentWitAdapterValueType.primitive({required String text, required WasmComponentPrimitiveValueType primitive})
Creates a primitive WIT adapter value type.
WASIComponentWitAdapterValueType.record({required String text, required List<WASIComponentWitAdapterRecordField> fields})
Creates a named WIT record adapter value type.
WASIComponentWitAdapterValueType.resource({required String text, required String resourceName, required bool isBorrowed})
Creates a local WIT resource handle adapter value type.
WASIComponentWitAdapterValueType.result({required String text, required WASIComponentWitAdapterValueType? ok, required WASIComponentWitAdapterValueType? error})
Creates a result<T, E> WIT adapter value type.
WASIComponentWitAdapterValueType.stream({required String text, required WASIComponentWitAdapterValueType element})
Creates a stream<T> WIT adapter value type.
WASIComponentWitAdapterValueType.tuple({required String text, required List<WASIComponentWitAdapterValueType> elements})
Creates a tuple<T...> WIT adapter value type.
WASIComponentWitAdapterValueType.variant({required String text, required List<WASIComponentWitAdapterVariantCase> cases})
Creates a named WIT variant adapter value type.

Properties

cases List<WASIComponentWitAdapterVariantCase>
Variant case types.
final
element WASIComponentWitAdapterValueType?
Option payload type.
final
elements List<WASIComponentWitAdapterValueType>
Tuple element types.
final
error WASIComponentWitAdapterValueType?
Result error payload type.
final
fields List<WASIComponentWitAdapterRecordField>
Record field types.
final
hashCode int
The hash code for this object.
no setterinherited
isBorrowedResource bool
Whether a resource-handle value is declared as borrow<T>.
final
kind WASIComponentWitAdapterValueKind
WIT adapter value category.
final
labels List<String>
Labels used by WIT flags and enum adapter value types.
final
ok WASIComponentWitAdapterValueType?
Result success payload type.
final
primitive WasmComponentPrimitiveValueType?
Component-model primitive represented by text, for primitive values.
final
resourceName String?
Local WIT resource name for resource-handle values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
WIT spelling.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited