WASIComponentWitAdapterVariantCase class final

WIT adapter variant case type.

Constructors

WASIComponentWitAdapterVariantCase({required String name, required WASIComponentWitAdapterValueType? type})
Creates a WIT adapter variant case type.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
WIT variant case name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type WASIComponentWitAdapterValueType?
Case payload type, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited