WASIComponentWitFunction class final

Function boundary declared directly in a WIT interface.

Constructors

WASIComponentWitFunction({required String name, required String signature, required WASIComponentWitSpan span})
Creates a WIT function boundary.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isAsync bool
Whether the signature is an async func.
no setter
name String
Function name before :.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
Compact signature text after : and before ;.
final
span WASIComponentWitSpan
Source span for the function name.
final
usesPreview3AsyncFeatures bool
Whether this function uses Preview3-native async surface syntax.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited