WASIComponentWitSpan class final

Source span used for WIT diagnostics.

Constructors

WASIComponentWitSpan({required String sourceName, required int offset, required int line, required int column, required int length})
Creates a source span.
const

Properties

column int
One-based column number.
final
hashCode int
The hash code for this object.
no setterinherited
length int
Span length in UTF-16 code units.
final
line int
One-based line number.
final
location String
source:line:column diagnostic location.
no setter
offset int
Zero-based byte-like string offset in the Dart source string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceName String
Human-readable source name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited