WASIComponentWitWorldItemDirection enum

Direction of a WIT world boundary item.

Inheritance
Available extensions

Values

import → const WASIComponentWitWorldItemDirection

import world item.

export → const WASIComponentWitWorldItemDirection

export world item.

include → const WASIComponentWitWorldItemDirection

include world item.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WASIComponentWitWorldItemDirection>
A constant List of the values in this enum, in order of their declaration.