WASIPreview1SocketSendHandler typedef

WASIPreview1SocketSendHandler = int Function(Uint8List source, int sourceStart, int length)

Handles stream bytes written through a host-backed Preview1 socket.

Return the number of bytes accepted by the host. Returning fewer than length bytes makes the current sock_send stop at that partial write.

Implementation

typedef WASIPreview1SocketSendHandler =
    int Function(Uint8List source, int sourceStart, int length);