WASIPreview2FilesystemMutationError enum

Filesystem mutation failures that map directly to WASI 0.2 error-code enum cases.

Inheritance
Available extensions

Values

access → const WASIPreview2FilesystemMutationError

Host permission denied.

const WASIPreview2FilesystemMutationError('access')
wouldBlock → const WASIPreview2FilesystemMutationError

Operation would block.

const WASIPreview2FilesystemMutationError('would-block')
exist → const WASIPreview2FilesystemMutationError

Target already exists.

const WASIPreview2FilesystemMutationError('exist')
invalid → const WASIPreview2FilesystemMutationError

Invalid path, offset, or argument.

const WASIPreview2FilesystemMutationError('invalid')
io → const WASIPreview2FilesystemMutationError

Host I/O failure.

const WASIPreview2FilesystemMutationError('io')
isDirectory → const WASIPreview2FilesystemMutationError

A directory was used where a regular file was required.

const WASIPreview2FilesystemMutationError('is-directory')
noEntry → const WASIPreview2FilesystemMutationError

Target path does not exist.

const WASIPreview2FilesystemMutationError('no-entry')
notDirectory → const WASIPreview2FilesystemMutationError

A non-directory was used where a directory was required.

const WASIPreview2FilesystemMutationError('not-directory')
notEmpty → const WASIPreview2FilesystemMutationError

Directory removal targeted a non-empty directory.

const WASIPreview2FilesystemMutationError('not-empty')
notPermitted → const WASIPreview2FilesystemMutationError

Path escaped the permitted preopen tree.

const WASIPreview2FilesystemMutationError('not-permitted')
readOnly → const WASIPreview2FilesystemMutationError

Descriptor or backing store is read-only.

const WASIPreview2FilesystemMutationError('read-only')
unsupported → const WASIPreview2FilesystemMutationError

Operation is not supported by the host backing store.

const WASIPreview2FilesystemMutationError('unsupported')

Properties

errorCode String
WIT error-code enum label.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WASIPreview2FilesystemMutationError>
A constant List of the values in this enum, in order of their declaration.