WASIPreview2HttpFields class final

Preview2 HTTP fields resource.

Constructors

WASIPreview2HttpFields({List<WASIPreview2HttpFieldEntry> entries = const <WASIPreview2HttpFieldEntry>[], bool mutable = true})
Creates HTTP fields from entries.

Properties

entries List<WASIPreview2HttpFieldEntry>
Returns all entries in serialization order.
no setter
hashCode int
The hash code for this object.
no setterinherited
mutable bool
Whether mutation APIs are allowed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

append(String name, List<int> value) String?
Appends one value for name.
delete(String name) String?
Deletes all values for name.
has(String name) bool
Returns whether name has at least one value.
immutableClone() WASIPreview2HttpFields
Returns an immutable clone.
mutableClone() WASIPreview2HttpFields
Returns a mutable clone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String name, List<List<int>> values) String?
Replaces all values for name.
toString() String
A string representation of this object.
inherited
values(String name) List<List<int>>
Returns all values for name, matching names case-insensitively.

Operators

operator ==(Object other) bool
The equality operator.
inherited