WASIPreview2HttpFutureTrailers class final

Future trailers resource.

Constructors

WASIPreview2HttpFutureTrailers(Future<WASIPreview2HttpResult<WASIPreview2HttpFields?>> future)
Creates pending future trailers.
WASIPreview2HttpFutureTrailers.completed(WASIPreview2HttpResult<WASIPreview2HttpFields?> result)
Creates completed future trailers.

Properties

hashCode int
The hash code for this object.
no setterinherited
isReady bool
Whether the trailers are ready.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitReady() Future<void>
Waits for readiness.

Operators

operator ==(Object other) bool
The equality operator.
inherited