WASIPreview2HttpHost class base

WASI 0.2 wasi:http host imports.

Implementers

Constructors

WASIPreview2HttpHost({WASIComponentResourceTable? table, WASIPreview2PollHost? pollHost, WASIPreview2StreamsHost? streamsHost, WASIPreview2HttpBackend? backend, BigInt? maximumRequestTimeoutNanos})
Creates an HTTP host backed by backend.

Properties

backend WASIPreview2HttpBackend
Outgoing HTTP backend.
final
hashCode int
The hash code for this object.
no setterinherited
imports Map<String, WASIComponentWitAdapterCallback>
Standard wasi:http@0.2.0 import callbacks.
latefinal
maximumRequestTimeoutNanos BigInt?
Largest request timeout accepted by this host, or null when unbounded.
final
pollHost WASIPreview2PollHost
Poll host used by HTTP futures.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamsHost WASIPreview2StreamsHost
Streams host used by HTTP body resources.
final
table WASIComponentResourceTable
Shared resource table.
final

Methods

insertFields(WASIPreview2HttpFields fields) int
Inserts fields and returns a resource handle.
insertIncomingRequest(WASIPreview2HttpIncomingRequest request) int
Inserts request and returns a resource handle.
insertResponseOutparam(WASIPreview2HttpResponseOutparam outparam) int
Inserts outparam and returns a resource handle.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited