WASIPreview2HttpOutgoingRequest class final

Preview2 outgoing HTTP request.

Constructors

WASIPreview2HttpOutgoingRequest(WASIPreview2HttpFields headers)
Creates an outgoing request.

Properties

authority String?
Request authority.
getter/setter pair
bodyResource WASIPreview2HttpOutgoingBody?
Outgoing request body, when created.
no setter
hashCode int
The hash code for this object.
no setterinherited
headers WASIPreview2HttpFields
Request headers.
final
method WASIPreview2HttpMethod
Request method.
getter/setter pair
pathWithQuery String?
Request path and query.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme WASIPreview2HttpScheme?
Request scheme.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takeBody() WASIPreview2HttpOutgoingBody?
Returns the outgoing body on the first call, or null afterwards.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited