WASIPreview2IpSocketAddress class final

IP socket address used by WASI 0.2 sockets.

Constructors

WASIPreview2IpSocketAddress.ipv4({required int port, required int a, required int b, required int c, required int d})
Creates an IPv4 socket address.
WASIPreview2IpSocketAddress.ipv6({required int port, required int a, required int b, required int c, required int d, required int e, required int f, required int g, required int h, int flowInfo = 0, int scopeId = 0})
Creates an IPv6 socket address.

Properties

address WASIPreview2IpAddress
IP address.
final
family WASIPreview2IpAddressFamily
IP address family.
no setter
flowInfo int
IPv6 flow information, or zero for IPv4.
final
hashCode int
The hash code for this object.
no setterinherited
host String
Host string suitable for Dart networking APIs.
no setter
port int
TCP/UDP port.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeId int
IPv6 scope id, or zero for IPv4.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited