WASIPreview2NativeHttpHost class final

Stub for non-dart:io platforms.

Inheritance

Constructors

WASIPreview2NativeHttpHost({WASIComponentResourceTable? table, WASIPreview2PollHost? pollHost, WASIPreview2StreamsHost? streamsHost})
Throws because native HTTP requires dart:io.

Properties

backend WASIPreview2HttpBackend
Outgoing HTTP backend.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
imports Map<String, WASIComponentWitAdapterCallback>
Standard wasi:http@0.2.0 import callbacks.
latefinalinherited
maximumRequestTimeoutNanos BigInt?
Largest request timeout accepted by this host, or null when unbounded.
finalinherited
pollHost WASIPreview2PollHost
Poll host used by HTTP futures.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamsHost WASIPreview2StreamsHost
Streams host used by HTTP body resources.
finalinherited
table WASIComponentResourceTable
Shared resource table.
finalinherited

Methods

insertFields(WASIPreview2HttpFields fields) int
Inserts fields and returns a resource handle.
inherited
insertIncomingRequest(WASIPreview2HttpIncomingRequest request) int
Inserts request and returns a resource handle.
inherited
insertResponseOutparam(WASIPreview2HttpResponseOutparam outparam) int
Inserts outparam and returns a resource handle.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited