WASIPreview2OutgoingDatagram class final

Outgoing UDP datagram passed to a sockets backend.

Constructors

WASIPreview2OutgoingDatagram({required Uint8List data, WASIPreview2IpSocketAddress? remoteAddress})
Creates an outgoing datagram.
const

Properties

data Uint8List
Datagram payload.
final
hashCode int
The hash code for this object.
no setterinherited
remoteAddress WASIPreview2IpSocketAddress?
Destination address, or null to use the connected peer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited