WASIPreview2OutputStream class final

Host-owned WASI 0.2 output-stream.

Constructors

WASIPreview2OutputStream({int maxWriteSize = 65536, String? onWrite(Uint8List bytes)?})
Creates an output byte stream.

Properties

bytes List<int>
Bytes written to this stream.
no setter
hashCode int
The hash code for this object.
no setterinherited
isWritable bool
Whether this stream is ready to accept writes or report terminal state.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes this stream.
fail(String debugString) → void
Fails this stream with debugString.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited