WASIPreview2Pollable class final

Readiness source for WASI 0.2 wasi:io/poll.pollable.

Constructors

WASIPreview2Pollable({required bool isReady(), required Future<void> waitReady()})
Creates a pollable backed by readiness and wait callbacks.

Properties

hashCode int
The hash code for this object.
no setterinherited
isReady bool
Whether this pollable can complete without blocking.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

block() Future<void>
Waits until this pollable becomes ready.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited