WASIPreview2StreamsHost class final

WASI 0.2 wasi:io/streams host imports.

Constructors

WASIPreview2StreamsHost({WASIComponentResourceTable? table, WASIPreview2PollHost? pollHost, WASIPreview2IoErrorHost? errorHost})
Creates a streams host backed by table or shared host tables.
factory

Properties

errorHost WASIPreview2IoErrorHost
Error host used by stream-error.last-operation-failed.
final
hashCode int
The hash code for this object.
no setterinherited
imports Map<String, WASIComponentWitAdapterCallback>
Standard wasi:io/streams@0.2.0 import callbacks.
latefinal
pollHost WASIPreview2PollHost
Poll host used by stream subscribe.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table WASIComponentResourceTable
Component resource table that owns stream handles.
final

Methods

inputStream(int handle) WASIPreview2InputStream
Returns the input stream for handle.
insertInputStream(WASIPreview2InputStream stream) int
Inserts stream and returns an owned input-stream handle.
insertOutputStream([WASIPreview2OutputStream? stream]) int
Inserts stream and returns an owned output-stream handle.
insertPersistentInputStream(WASIPreview2InputStream stream) int
Inserts a host-owned input stream outside component runtime scopes.
insertPersistentOutputStream([WASIPreview2OutputStream? stream]) int
Inserts a host-owned output stream outside component runtime scopes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outputStream(int handle) WASIPreview2OutputStream
Returns the output stream for handle.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited