WASIPreview2UdpBinding class abstract interface

Bound UDP socket returned by a sockets backend.

Properties

canReceive bool
Whether a receive operation can make progress.
no setter
canSend bool
Whether a send operation can make progress.
no setter
hashCode int
The hash code for this object.
no setterinherited
localAddress WASIPreview2IpSocketAddress
Bound local address.
no setter
remoteAddress WASIPreview2IpSocketAddress?
Connected remote address, if the backend has one.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendCapacity BigInt
Max datagrams accepted by one send call.
no setter

Methods

close() → void
Closes the binding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receive(BigInt maxResults) WASIPreview2SocketResult<List<WASIPreview2IncomingDatagram>>
Receives up to maxResults datagrams.
send(List<WASIPreview2OutgoingDatagram> datagrams) WASIPreview2SocketResult<BigInt>
Sends datagrams.
toString() String
A string representation of this object.
inherited
waitReceive() Future<void>
Completes when receive may make progress.
waitSend() Future<void>
Completes when send may make progress.

Operators

operator ==(Object other) bool
The equality operator.
inherited