WASIPreview2UnsupportedSocketsBackend class final

Backend that reports unsupported for OS socket operations.

Implemented types

Constructors

WASIPreview2UnsupportedSocketsBackend()
Creates the default unsupported sockets backend.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTcpBind(WASIPreview2IpSocketAddress localAddress) WASIPreview2SocketOperation<WASIPreview2IpSocketAddress>
Starts TCP bind.
override
startTcpConnect({required WASIPreview2IpSocketAddress remoteAddress, WASIPreview2IpSocketAddress? localAddress}) WASIPreview2SocketOperation<WASIPreview2TcpConnection>
Starts TCP connect.
override
startTcpListen({required WASIPreview2IpSocketAddress localAddress, required BigInt backlog}) WASIPreview2SocketOperation<WASIPreview2TcpListener>
Starts TCP listen.
override
startUdpBind(WASIPreview2IpSocketAddress localAddress) WASIPreview2SocketOperation<WASIPreview2UdpBinding>
Starts UDP bind.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited