WASIPreview3AddressResolverError class final

A standardized DNS failure returned by WASIPreview3AddressResolver.

Implemented types

Constructors

WASIPreview3AddressResolverError(String errorCode)
Creates a DNS failure with a stable ip-name-lookup.error-code label.
const

Properties

errorCode String
DNS error variant label.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited