WASIPreview3CommandResult class final

Result returned after executing a WASI Preview3 command component.

Constructors

WASIPreview3CommandResult({required int exitCode})
Creates a command execution result.
const

Properties

exitCode int
Process-style exit code. 0 means success.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited