WASIPreview3FilesystemDirectory class final

Directory contents exposed through a WASI 0.3 filesystem preopen.

Constructors

WASIPreview3FilesystemDirectory({Iterable<WASIPreview3FilesystemDirectoryEntry> entries = const <WASIPreview3FilesystemDirectoryEntry>[], bool canMutate = false, Object? mutationContext, WASIPreview3FilesystemMetadataProvider? metadata, WASIPreview3FilesystemDirectoryMutationCallback? createDirectory, WASIPreview3FilesystemDirectoryFileCreateCallback? createFile, WASIPreview3FilesystemDirectoryLinkCallback? link, WASIPreview3FilesystemDirectoryRenameCallback? rename, WASIPreview3FilesystemDirectorySymlinkCallback? symlink, WASIPreview3FilesystemDirectoryReadLinkCallback? readLink, WASIPreview3FilesystemSetTimesCallback? setTimes, WASIPreview3FilesystemDirectoryMutationCallback? removeDirectory, WASIPreview3FilesystemDirectoryMutationCallback? unlinkFile, bool? createdFileCanMutate, bool createdFileSupportsSync = true, bool createdFileSupportsSyncData = true})
Creates a directory model with stable entries.
WASIPreview3FilesystemDirectory.dynamic({required WASIPreview3FilesystemDirectoryEntriesProvider entries, WASIPreview3FilesystemDirectoryEntryResolver? resolveEntry, bool canMutate = false, Object? mutationContext, WASIPreview3FilesystemMetadataProvider? metadata, WASIPreview3FilesystemDirectoryMutationCallback? createDirectory, WASIPreview3FilesystemDirectoryFileCreateCallback? createFile, WASIPreview3FilesystemDirectoryLinkCallback? link, WASIPreview3FilesystemDirectoryRenameCallback? rename, WASIPreview3FilesystemDirectorySymlinkCallback? symlink, WASIPreview3FilesystemDirectoryReadLinkCallback? readLink, WASIPreview3FilesystemSetTimesCallback? setTimes, WASIPreview3FilesystemDirectoryMutationCallback? removeDirectory, WASIPreview3FilesystemDirectoryMutationCallback? unlinkFile, bool? createdFileCanMutate, bool createdFileSupportsSync = false, bool createdFileSupportsSyncData = false})
Creates a directory whose contents are loaded from callbacks.

Properties

canMutate bool
Whether descriptors opened for this directory can request mutation flags.
final
createdFileCanMutate bool
Whether files created by this directory can be opened for mutation.
final
createdFileSupportsSync bool
Whether files created by this directory support sync.
final
createdFileSupportsSyncData bool
Whether files created by this directory support sync-data.
final
entries List<WASIPreview3FilesystemDirectoryEntry>
Entries returned by descriptor.read-directory.
no setter
hashCode int
The hash code for this object.
no setterinherited
mutationContext Object?
Opaque host-specific context available to mutation callbacks.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited