WASIPreview3FilesystemMutationResult class final

Result returned by Preview3 filesystem mutation callbacks.

Constructors

WASIPreview3FilesystemMutationResult.error(WASIPreview3FilesystemMutationError? error)
Creates a failed mutation result with a WASI filesystem error.
const
WASIPreview3FilesystemMutationResult.ok()
Creates a successful mutation result.
const

Properties

error WASIPreview3FilesystemMutationError?
WASI filesystem error reported by the mutation, or null on success.
final
hashCode int
The hash code for this object.
no setterinherited
isOk bool
Whether the mutation succeeded.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited