WASIPreview3HttpBackend class abstract interface

Backend used by Preview3 client.send and imported handler.handle.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(WASIPreview3HttpRequest request) FutureOr<WASIPreview3HttpResult<WASIPreview3HttpResponse>>
Handles an owned request and returns an owned response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited