WASIPreview3NativeSocketsHost class final

Placeholder for platforms without dart:io socket access.

Inheritance

Constructors

WASIPreview3NativeSocketsHost({WASIComponentResourceTable? table, WASIPreview3AddressResolver? resolveAddresses})
Throws because this platform cannot expose host sockets.

Properties

hashCode int
The hash code for this object.
no setterinherited
imports Map<String, WASIComponentWitAdapterCallback>
Stable wasi:sockets@0.3.0 import callbacks.
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table WASIComponentResourceTable
Shared component resource table.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited