WASIPreview3TcpSocketOptions class final

Effective TCP socket options supplied to a native endpoint.

Constructors

WASIPreview3TcpSocketOptions({required bool keepAliveEnabled, required BigInt keepAliveIdle, required BigInt keepAliveInterval, required int keepAliveCount, required int hopLimit, required BigInt receiveBufferSize, required BigInt sendBufferSize})
Creates an immutable TCP option snapshot.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hopLimit int
IPv4 TTL or IPv6 unicast hop limit.
final
keepAliveCount int
Number of failed probes before termination.
final
keepAliveEnabled bool
Whether TCP keepalive is enabled.
final
keepAliveIdle BigInt
Keepalive idle duration in nanoseconds.
final
keepAliveInterval BigInt
Keepalive interval in nanoseconds.
final
receiveBufferSize BigInt
Requested receive buffer size.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendBufferSize BigInt
Requested send buffer size.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited