WasiInMemoryFileSystem class final

Implemented types

Constructors

WasiInMemoryFileSystem()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDirectory(String path) → void
override
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({required String path, required bool create, required bool truncate, required bool read, required bool write, required bool exclusive, required bool followSymlinks}) WasiFileDescriptor
override
readDirectory(String path) List<WasiDirectoryEntry>
override
readFileBytes(String path) Uint8List?
readFileText(String path, {Encoding encoding = utf8}) String?
override
removeDirectory(String path) → void
override
rename({required String sourcePath, required String destinationPath}) → void
override
setPathTimes({required String path, int? atimeNs, int? mtimeNs, int? ctimeNs, required bool followSymlinks}) → void
override
snapshot() Map<String, Uint8List>
snapshotDirectories() List<String>
statPath(String path, {required bool followSymlinks}) WasiPathStat
override
override
toString() String
A string representation of this object.
inherited
unlinkFile(String path) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

normalizeAbsolutePath(String path) String