WasmComponentAliasTarget class final

Constructors

WasmComponentAliasTarget.coreExport({required int? coreInstanceIndex, required String? name})
const
WasmComponentAliasTarget.export({required int? instanceIndex, required String? name})
const
WasmComponentAliasTarget.outer({required int? componentDepth, required int? index})
const

Properties

componentDepth int?
final
coreInstanceIndex int?
final
hashCode int
The hash code for this object.
no setterinherited
index int?
final
instanceIndex int?
final
kind WasmComponentAliasTargetKind
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited