WasmComponentCoreInstance class final
Constructors
-
WasmComponentCoreInstance.inlineExports({required List<
WasmComponentCoreInlineExport> exports}) -
const
-
WasmComponentCoreInstance.instantiate({required int? moduleIndex, required List<
WasmComponentCoreInstantiationArgument> arguments}) -
const
Properties
-
arguments
→ List<
WasmComponentCoreInstantiationArgument> -
final
-
exports
→ List<
WasmComponentCoreInlineExport> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WasmComponentCoreInstanceKind
-
final
- moduleIndex → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited