WasmComponentExternDescriptor class final
Constructors
- WasmComponentExternDescriptor({required WasmComponentExternKind kind, WasmComponentExternBoundKind boundKind = WasmComponentExternBoundKind.none, WasmComponentCoreSortKind? coreKind, int? typeIndex, int? valueIndex, WasmComponentValueType? valueType, int? valueTypeCode})
-
const
Properties
- boundKind → WasmComponentExternBoundKind
-
final
- coreKind → WasmComponentCoreSortKind?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WasmComponentExternKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeIndex → int?
-
final
- valueIndex → int?
-
final
- valueType → WasmComponentValueType?
-
final
- valueTypeCode → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited