WasmComponentValueData class final

Constructors

WasmComponentValueData({required WasmComponentValueDataKind kind, required Uint8List rawBytes, bool? boolean, Object? integer, double? floatingPoint, String? string, List<WasmComponentValueData> items = const <WasmComponentValueData>[], List<Object?>? runtimeItems, int? index, String? label, List<String> labels = const <String>[], WasmComponentValueData? associatedValue, Object? associatedPayload, bool? isSome, bool? isOk})

Properties

associatedPayload Object?
Nested runtime payload that cannot be represented by WasmComponentValueData, such as a stream or future endpoint.
final
associatedValue WasmComponentValueData?
Nested statically representable component value data.
final
boolean bool?
final
floatingPoint double?
final
hashCode int
The hash code for this object.
no setterinherited
index int?
final
integer Object?
final
isOk bool?
final
isSome bool?
final
items List<WasmComponentValueData>
final
itemValues List<Object?>
Composite items regardless of whether they contain runtime-only values.
no setter
kind WasmComponentValueDataKind
final
label String?
final
labels List<String>
final
payload Object?
The nested payload regardless of whether it is static or runtime-only.
no setter
rawBytes Uint8List
final
runtimeItems List<Object?>?
Composite items containing runtime-only values such as stream or future endpoints. Static composites continue to use items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited