associatedPayload property
Nested runtime payload that cannot be represented by WasmComponentValueData, such as a stream or future endpoint.
Implementation
final Object? associatedPayload;
Nested runtime payload that cannot be represented by WasmComponentValueData, such as a stream or future endpoint.
final Object? associatedPayload;