WasmComponentValueDataKind enum

Inheritance
Available extensions

Values

boolean → const WasmComponentValueDataKind
integer → const WasmComponentValueDataKind
floatingPoint → const WasmComponentValueDataKind
string → const WasmComponentValueDataKind
tuple → const WasmComponentValueDataKind
record → const WasmComponentValueDataKind
list → const WasmComponentValueDataKind
fixedList → const WasmComponentValueDataKind
variant → const WasmComponentValueDataKind
flags → const WasmComponentValueDataKind
enumeration → const WasmComponentValueDataKind
option → const WasmComponentValueDataKind
result → const WasmComponentValueDataKind
raw → const WasmComponentValueDataKind

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WasmComponentValueDataKind>
A constant List of the values in this enum, in order of their declaration.