WasmFunction typedef

WasmFunction = Object? Function(List<Object?>)

The Dart calling convention for host functions passed to or received from WebAssembly: arguments are delivered as a List and the return value is nullable.

Implementation

typedef WasmFunction = Object? Function(List<Object?>);