WasmInstance class final

Constructors

WasmInstance.fromBytes(Uint8List wasmBytes, {WasmImports imports = const WasmImports(), WasmFeatureSet features = const WasmFeatureSet()})
factory
WasmInstance.fromModule(WasmModule module, {WasmImports imports = const WasmImports(), WasmFeatureSet features = const WasmFeatureSet()})
factory

Properties

exportedFunctions List<String>
no setter
exportedGlobals List<String>
no setter
exportedMemories List<String>
no setter
exportedTables List<String>
no setter
functions List<RuntimeFunction>
final
globals List<RuntimeGlobal>
final
hashCode int
The hash code for this object.
no setterinherited
memory WasmMemory?
final
module WasmModule
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<WasmTable>
final

Methods

exportedMemory(String exportName) WasmMemory
exportedTable(String exportName) WasmTable
invoke(String exportName, [List<Object?> args = const []]) Object?
invokeF32(String exportName, [List<Object?> args = const []]) double
invokeF64(String exportName, [List<Object?> args = const []]) double
invokeI32(String exportName, [List<Object?> args = const []]) int
invokeI64(String exportName, [List<Object?> args = const []]) int
invokeMulti(String exportName, [List<Object?> args = const []]) List<Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readGlobal(String exportName) Object
readGlobalF32(String exportName) double
readGlobalF64(String exportName) double
readGlobalI32(String exportName) int
readGlobalI64(String exportName) int
toString() String
A string representation of this object.
inherited
writeGlobal(String exportName, Object? value) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited