TagDescriptor class
Describes the payload signature of a WebAssembly exception tag.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
→ List<
ValueKind< Value< >dynamic, Object?> , Object?> -
Ordered value kinds of payload fields associated with this tag.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited