TagImportExportValue class final
Tag import/export value wrapper.
- Inheritance
-
- Object
- ImportExportValue<
Tag> - ExportValue<
Tag, TagImportExportValue> - TagImportExportValue
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kind
→ ImportExportKind<
Tag, TagImportExportValue> -
Kind marker of this export value.
no setteroverride
- ref → Tag
-
Wrapped reference value.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited