WASIComponentAsyncValueMemoryLayout class final
Canonical ABI memory-copy layout for an async value payload.
Properties
- alignment → int
-
Required guest-memory alignment for the element record pointer.
final
- byteLength → int
-
Number of guest-memory bytes per stream/future element record.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited