WASIComponentCanonicalAsyncOperation class final
Executable form of a canonical stream/future operation.
Properties
- componentTypeIndex → int?
-
Component type index the operation targets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAsync → bool
-
Whether this canonical operation was decoded with the async flag.
final
- kind → WasmComponentCanonicalKind
-
Canonical async operation kind.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringEncoding → WASIComponentCanonicalStringEncoding
-
Canonical string encoding configured by decoded operation options.
final
Methods
-
backpressureDecrement(
) → int -
Executes
backpressure.dec. -
backpressureIncrement(
) → int -
Executes
backpressure.inc. -
backpressureSet(
bool active) → int -
Executes
backpressure.set. -
futureCancelRead(
Object? readable) → void -
Executes
future.cancel-read. -
futureCancelReadHandle(
int readable) → int -
Executes
future.cancel-readwith a readable endpoint handle. -
futureCancelReadHandleWhenReady(
int readable) → Future< int> -
Executes
future.cancel-readwith a readable endpoint handle, waiting for the copy event when the canonical operation is synchronous. -
futureCancelWrite(
Object? writable) → void -
Executes
future.cancel-write. -
futureCancelWriteHandle(
int writable) → int -
Executes
future.cancel-writewith a writable endpoint handle. -
futureCancelWriteHandleWhenReady(
int writable) → Future< int> -
Executes
future.cancel-writewith a writable endpoint handle, waiting for the copy event when the canonical operation is synchronous. -
futureDropReadable(
Object? readable) → void -
Executes
future.drop-readable. -
futureDropReadableHandle(
int readable) → void -
Executes
future.drop-readablewith a readable endpoint handle. -
futureDropWritable(
Object? writable) → void -
Executes
future.drop-writable. -
futureDropWritableHandle(
int writable) → void -
Executes
future.drop-writablewith a writable endpoint handle. -
futureNew(
) → Object -
Executes
future.new. -
futureNewHandles(
) → WASIComponentAsyncEndpointHandles -
Executes
future.newand returns endpoint handles. -
futureNewPackedHandles(
) → int -
Executes
future.newand returns the canonical packed handle pair. -
futureRead(
Object? readable) → Object? -
Executes
future.read. -
futureReadHandle(
int readable) → Object? -
Executes
future.readwith a readable endpoint handle. -
futureReadHandleToMemory(
int readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) → WASIComponentAsyncCopyResult -
Executes handle-backed
future.readinto memory. -
futureReadHandleToMemoryEvent(
int readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) → int -
Starts handle-backed
future.readinto memory and publishes an event. -
futureReadHandleToMemoryWhenReady(
int readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) → Future< WASIComponentAsyncCopyResult> -
Executes handle-backed
future.readinto memory when ready. -
futureReadHandleWhenReady(
int readable) → Future< Object?> -
Executes
future.readwith a readable endpoint handle and waits if pending. -
futureReadToMemory(
Object? readable, Memory memory, int pointer, [WASIComponentCanonicalRealloc? realloc]) → WASIComponentAsyncCopyResult -
Executes
future.readand writes a value tomemory. -
futureReadWhenReady(
Object? readable) → Future< Object?> -
Executes
future.readand waits if the future is still pending. -
futureWrite(
Object? writable, Object? value) → void -
Executes
future.write. -
futureWriteFromMemory(
Object? writable, Memory memory, int pointer) → WASIComponentAsyncCopyResult -
Executes
future.writeby reading a value frommemory. -
futureWriteHandle(
int writable, Object? value) → void -
Executes
future.writewith a writable endpoint handle. -
futureWriteHandleFromMemory(
int writable, Memory memory, int pointer) → WASIComponentAsyncCopyResult -
Executes handle-backed
future.writefrom memory. -
futureWriteHandleFromMemoryEvent(
int writable, Memory memory, int pointer) → int -
Starts handle-backed
future.writefrom memory and publishes an event. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
streamCancelRead(
Object? readable) → void -
Executes
stream.cancel-read. -
streamCancelReadHandle(
int readable) → int -
Executes
stream.cancel-readwith a readable endpoint handle. -
streamCancelReadHandleWhenReady(
int readable) → Future< int> -
Executes
stream.cancel-readwith a readable endpoint handle, waiting for the copy event when the canonical operation is synchronous. -
streamCancelWrite(
Object? writable) → void -
Executes
stream.cancel-write. -
streamCancelWriteHandle(
int writable) → int -
Executes
stream.cancel-writewith a writable endpoint handle. -
streamCancelWriteHandleWhenReady(
int writable) → Future< int> -
Executes
stream.cancel-writewith a writable endpoint handle, waiting for the copy event when the canonical operation is synchronous. -
streamDropReadable(
Object? readable) → void -
Executes
stream.drop-readable. -
streamDropReadableHandle(
int readable) → void -
Executes
stream.drop-readablewith a readable endpoint handle. -
streamDropWritable(
Object? writable) → void -
Executes
stream.drop-writable. -
streamDropWritableHandle(
int writable) → void -
Executes
stream.drop-writablewith a writable endpoint handle. -
streamNew(
) → Object -
Executes
stream.new. -
streamNewHandles(
) → WASIComponentAsyncEndpointHandles -
Executes
stream.newand returns endpoint handles. -
streamNewPackedHandles(
) → int -
Executes
stream.newand returns the canonical packed handle pair. -
streamRead(
Object? readable, int maxElements) → List< Object?> -
Executes
stream.read. -
streamReadHandle(
int readable, int maxElements) → List< Object?> -
Executes
stream.readwith a readable endpoint handle. -
streamReadHandleToMemory(
int readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) → WASIComponentAsyncCopyResult -
Executes handle-backed
stream.readinto memory elements. -
streamReadHandleToMemoryEvent(
int readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) → int -
Starts handle-backed
stream.readinto memory and publishes an event. -
streamReadHandleToMemoryWhenAvailable(
int readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) → Future< WASIComponentAsyncCopyResult> -
Executes handle-backed
stream.readinto memory when values exist. -
streamReadHandleWhenAvailable(
int readable, int maxElements) → Future< List< Object?> > -
Executes
stream.readwith a readable endpoint handle and waits if the stream has no queued values. -
streamReadToMemory(
Object? readable, Memory memory, int pointer, int maxElements, [WASIComponentCanonicalRealloc? realloc]) → WASIComponentAsyncCopyResult -
Executes
stream.readand writes elements tomemory. -
streamReadWhenAvailable(
Object? readable, int maxElements) → Future< List< Object?> > -
Executes
stream.readand waits if the stream has no queued values. -
streamWrite(
Object? writable, Object? values) → int -
Executes
stream.write. -
streamWriteFromMemory(
Object? writable, Memory memory, int pointer, int elementCount) → WASIComponentAsyncCopyResult -
Executes
stream.writeby reading elements frommemory. -
streamWriteHandle(
int writable, Object? values) → int -
Executes
stream.writewith a writable endpoint handle. -
streamWriteHandleFromMemory(
int writable, Memory memory, int pointer, int elementCount) → WASIComponentAsyncCopyResult -
Executes handle-backed
stream.writefrom memory elements. -
streamWriteHandleFromMemoryEvent(
int writable, Memory memory, int pointer, int elementCount) → int -
Starts handle-backed
stream.writefrom memory and publishes an event. -
streamWriteHandleFromMemoryWhenAvailable(
int writable, Memory memory, int pointer, int elementCount) → Future< WASIComponentAsyncCopyResult> -
Executes handle-backed
stream.writefrom memory when capacity exists. -
streamWriteHandleWhenAvailable(
int writable, Object? values) → Future< int> -
Executes
stream.writewith a writable endpoint handle and waits if the stream has no write capacity. -
streamWriteWhenAvailable(
Object? writable, Object? values) → Future< int> -
Executes
stream.writeand waits if the stream has no write capacity. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited