WASIComponentCanonicalCapabilityArea enum
Functional area covered by a Component Model canonical operation.
Values
- adapterGeneration → const WASIComponentCanonicalCapabilityArea
-
Typed core function adapter generation for canonical lift/lower.
- resource → const WASIComponentCanonicalCapabilityArea
-
Canonical component resource operations.
- asyncValue → const WASIComponentCanonicalCapabilityArea
-
P3 async stream/future/backpressure operations.
- waitable → const WASIComponentCanonicalCapabilityArea
-
P3 waitable set operations.
- subtask → const WASIComponentCanonicalCapabilityArea
-
Caller-side subtask operations.
- task → const WASIComponentCanonicalCapabilityArea
-
Callee-side task operations.
- context → const WASIComponentCanonicalCapabilityArea
-
Component context get/set operations.
- threadIdentity → const WASIComponentCanonicalCapabilityArea
-
Thread identity and availability operations.
- threadScheduling → const WASIComponentCanonicalCapabilityArea
-
Scheduler-dependent thread operations.
- errorContext → const WASIComponentCanonicalCapabilityArea
-
Error-context lifecycle and debug-message operations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WASIComponentCanonicalCapabilityArea> - A constant List of the values in this enum, in order of their declaration.