WASIComponentCanonicalHost class final
Component Model canonical host facade.
This binds the canonical builtins implemented by the focused component hosts into one canonical-indexed program so versioned WASI adapters can use one execution boundary.
Constructors
- WASIComponentCanonicalHost({WASIComponentResourceTable? table, WASIComponentBackpressure? backpressure, WASIComponentContext? context, int availableParallelism = 1})
- Creates a canonical host over shared component runtime state.
Properties
- adapterHost ↔ WASIComponentCanonicalAdapterHost
-
Adapter host used for executable canonical
lift/loweroperations.latefinal - asyncHost ↔ WASIComponentAsyncHost
-
Async host used for canonical
stream.*,future.*, and backpressure.latefinal -
canonicalKindCapabilities
→ List<
WASIComponentCanonicalKindCapability> -
Describes this host's support for every decoded canonical kind.
no setter
- contextHost ↔ WASIComponentContextHost
-
Context host used for canonical
context.*operations.latefinal - errorContextHost ↔ WASIComponentErrorContextHost
-
Error-context host used for canonical
error-context.*operations.latefinal - hashCode → int
-
The hash code for this object.
no setterinherited
- resourceHost ↔ WASIComponentResourceHost
-
Resource host used for canonical
resource.*operations.latefinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtaskHost ↔ WASIComponentSubtaskHost
-
Subtask host used for canonical
subtask.*operations.latefinal - table → WASIComponentResourceTable
-
Shared component resource table.
final
- taskHost ↔ WASIComponentTaskHost
-
Callee task host used for canonical
task.*operations.latefinal - threadHost ↔ WASIComponentThreadHost
-
Thread host used for supported canonical
thread.*identity operations.latefinal - waitableHost ↔ WASIComponentWaitableHost
-
Waitable host used for canonical
waitable.*operations.latefinal
Methods
-
bindCanonicalDefinition(
WasmComponentCanonicalDefinition definition) → WASIComponentCanonicalOperation - Binds one decoded canonical definition.
-
bindCanonicalDefinitions(
Iterable< WasmComponentCanonicalDefinition> definitions) → WASIComponentCanonicalProgram - Binds canonical definitions in their decoded canonical index order.
-
bindComponent(
WasmComponent component, {bool validate = true}) → WASIComponentCanonicalProgram -
Binds decoded canonical definitions from
component. -
canonicalKindCapability(
WasmComponentCanonicalKind kind) → WASIComponentCanonicalKindCapability -
Describes this host's support for one decoded canonical
kind. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareComponent(
WasmComponent component, {bool validate = true}) → WASIComponentCanonicalBindingPlan - Builds a reusable component binding plan without partially binding.
-
supportsCanonicalKind(
WasmComponentCanonicalKind kind) → bool -
Returns
truewhen this host can bind canonicalkind. -
toString(
) → String -
A string representation of this object.
inherited
-
unsupportedCanonicalDefinitions(
Iterable< WasmComponentCanonicalDefinition> definitions) → List<WASIComponentCanonicalHostUnsupportedDefinition> - Reports unsupported definitions without partially binding a program.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited