WASIComponentCanonicalHostUnsupportedException class final
Thrown when canonical definitions require unsupported host capabilities.
- Implemented types
Constructors
-
WASIComponentCanonicalHostUnsupportedException(Iterable<
WASIComponentCanonicalHostUnsupportedDefinition> definitions) -
Creates an exception from unsupported
definitions.
Properties
-
definitions
→ List<
WASIComponentCanonicalHostUnsupportedDefinition> -
Unsupported definitions that blocked binding.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited