WASIComponentCanonicalProgram class final
Bound canonical program preserving component canonical index order.
Constructors
-
WASIComponentCanonicalProgram({required List<
WASIComponentCanonicalOperation> operations}) -
Creates a bound program from
operations.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
operations
→ List<
WASIComponentCanonicalOperation> -
Bound operations in component canonical definition order.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invoke(
int canonicalIndex, List< Object?> args) → Object? - Invokes a canonical operation by canonical index.
-
invokeAsync(
int canonicalIndex, List< Object?> args) → Future<Object?> - Invokes a canonical operation and waits when the operation supports it.
-
invokeFlat(
int canonicalIndex, List< Object?> args, {Memory? memory, WASIComponentCanonicalRealloc? realloc}) → List<Object?> - Invokes a flat Canonical ABI operation by canonical index.
-
invokeFlatAsync(
int canonicalIndex, List< Object?> args, {Memory? memory, WASIComponentCanonicalRealloc? realloc}) → Future<List< Object?> > - Invokes a flat Canonical ABI operation by canonical index and waits when supported.
-
invokeWithMemory(
int canonicalIndex, Memory memory, List< Object?> args, {int? resultPointer, WASIComponentCanonicalRealloc? realloc}) → Object? - Invokes a memory-backed canonical operation.
-
invokeWithMemoryAsync(
int canonicalIndex, Memory memory, List< Object?> args, {int? resultPointer, WASIComponentCanonicalRealloc? realloc}) → Future<Object?> - Invokes a memory-backed canonical operation and waits if needed.
-
invokeWithMemoryEvent(
int canonicalIndex, Memory memory, List< Object?> args, {int? resultPointer, WASIComponentCanonicalRealloc? realloc}) → Object? - Starts a memory-backed canonical event operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited