WASIComponentFuture<T> class
final
In-memory runtime state for a Component Model future<T> value.
Constructors
- WASIComponentFuture(String name, {void onDrop()?, void onReadableDrop()?, void onDiscard(T value)?})
-
Creates a future with a debug
name.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
Whether the future has been cancelled.
no setter
- isDropped → bool
-
Whether both endpoints have been dropped.
no setter
- name → String
-
Debug label used in diagnostics.
no setter
-
readable
↔ WASIComponentReadableFuture<
T> -
Readable endpoint.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
writable
↔ WASIComponentWritableFuture<
T> -
Writable endpoint.
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited