WASIComponentHost class final
Component host adapter over shared WASI component primitives.
This adapter coordinates decoded component validation, resource type binding, and canonical builtin binding.
Constructors
- WASIComponentHost({WASIComponentCanonicalHost? canonicalHost})
-
Creates a component host over
canonicalHostor a new shared host.
Properties
- canonicalHost → WASIComponentCanonicalHost
-
Shared canonical host used by this component adapter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → WASIComponentResourceTable
-
Shared resource table used by all component hosts.
no setter
Methods
-
bindComponent(
WasmComponent component, {bool validate = true, Map< int, WASIComponentCanonicalAdapterCallback> coreFunctions = const <int, WASIComponentCanonicalAdapterCallback>{}, Map<int, WASIComponentCanonicalAdapterCallback> componentFunctions = const <int, WASIComponentCanonicalAdapterCallback>{}, String resourceName(WASIComponentResourceBinding binding)?, void onResourceDrop(WASIComponentResourceBinding binding, Object resource)?, String asyncValueName(WASIComponentAsyncValueBinding binding)?, int? maxBufferedElementsForStream(WASIComponentAsyncValueBinding binding)?, void onAsyncValueDrop(WASIComponentAsyncValueBinding binding)?}) → WASIComponentHostBinding -
Prepares and binds
component. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareComponent(
WasmComponent component, {bool validate = true}) → WASIComponentHostBindingPlan - Prepares a decoded component for host binding without side effects.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited