WASIComponentHostBindingPlan class final
Prepared component host binding report.
Properties
-
adapterPlans
→ List<
WASIComponentCanonicalAdapterPlan> -
Canonical
lift/loweradapter plans captured before host binding.final -
asyncValueBindings
→ List<
WASIComponentAsyncValueBinding> -
Component async stream/future bindings captured before host binding.
final
-
bindingErrors
→ List<
WASIComponentHostBindingError> -
Host-specific binding gaps that must be wired before binding.
final
- canBind → bool
-
Whether bind can build a component host binding without throwing.
no setter
- canBindWithAdapters → bool
-
Whether bind can build when executable adapter callbacks are supplied.
no setter
- canonicalPlan → WASIComponentCanonicalBindingPlan
-
Prepared canonical binding plan for the same component.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceBindings
→ List<
WASIComponentResourceBinding> -
Component resource bindings captured before host binding.
final
-
resourceUses
→ List<
WASIComponentResourceUse> -
Canonical adapter resource-handle uses captured before host binding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unsupportedDefinitions
→ List<
WASIComponentCanonicalHostUnsupportedDefinition> -
Unsupported canonical definitions that this host cannot bind.
no setter
-
validationErrors
→ List<
WasmComponentValidationError> -
Component validation errors that must be fixed before binding.
no setter
Methods
-
bind(
{Map< int, WASIComponentCanonicalAdapterCallback> coreFunctions = const <int, WASIComponentCanonicalAdapterCallback>{}, Map<int, WASIComponentCanonicalAdapterCallback> componentFunctions = const <int, WASIComponentCanonicalAdapterCallback>{}, String resourceName(WASIComponentResourceBinding binding)?, void onResourceDrop(WASIComponentResourceBinding binding, Object resource)?, String asyncValueName(WASIComponentAsyncValueBinding binding)?, int? maxBufferedElementsForStream(WASIComponentAsyncValueBinding binding)?, void onAsyncValueDrop(WASIComponentAsyncValueBinding binding)?}) → WASIComponentHostBinding - Defines component resources and binds the canonical builtin program.
-
bindAdapters(
{Map< int, WASIComponentCanonicalAdapterCallback> coreFunctions = const <int, WASIComponentCanonicalAdapterCallback>{}, Map<int, WASIComponentCanonicalAdapterCallback> componentFunctions = const <int, WASIComponentCanonicalAdapterCallback>{}}) → WASIComponentCanonicalAdapterProgram -
Binds direct primitive canonical
lift/loweradapter operations. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited