WASIComponentMemoryString class final
Result of writing a canonical string to component memory.
Constructors
- WASIComponentMemoryString({required int pointer, required int canonicalLength, required int byteLength})
-
Creates a memory string range.
const
Properties
- byteLength → int
-
Byte length of the string payload in guest memory.
final
- canonicalLength → int
-
Canonical ABI string length value paired with pointer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointer → int
-
Pointer to the first byte in guest memory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited