WASIComponentReadableStream<T> class final

Readable endpoint for WASIComponentStream.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasQueuedValues bool
Whether at least one value is currently queued for reading.
no setter
isCancelled bool
Whether reads have been cancelled.
no setter
isDropped bool
Whether this endpoint has been dropped.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels future reads and discards queued values.
drop() → void
Drops this endpoint.
forwardTo(WASIComponentWritableStream<T> writable, int maxElements, {int chunkSize = 1}) Future<int>
Forwards up to maxElements values into writable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int maxElements) List<T>
Reads up to maxElements queued values.
readWhenAvailable(int maxElements) Future<List<T>>
Returns a Dart future that completes when values or stream closure arrive.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited