WASIComponentSubtaskHost class final
Table-backed host for canonical subtask operations.
Constructors
- WASIComponentSubtaskHost({WASIComponentResourceTable? table})
-
Creates a subtask host backed by
tableor a new resource table.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → WASIComponentResourceTable
-
Resource table used for subtasks.
final
Methods
-
bindCanonicalDefinition(
WasmComponentCanonicalDefinition definition) → WASIComponentCanonicalSubtaskOperation - Binds a decoded canonical subtask definition.
-
bindCanonicalDefinitions(
WasmComponent component) → WASIComponentCanonicalSubtaskProgram -
Binds all decoded canonical subtask definitions in
component. -
createSubtask(
{String name = 'subtask', WASIComponentSubtaskState state = WASIComponentSubtaskState.starting, void onCancel(WASIComponentSubtask subtask)?}) → int - Creates a subtask and returns its canonical handle.
-
insertSubtask(
WASIComponentSubtask subtask) → int -
Inserts
subtaskand returns its canonical handle. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subtaskCancel(
int subtask, {required bool isAsync}) → int -
Executes
subtask.cancel. -
subtaskCancelWhenReady(
int subtask, {required bool isAsync}) → Future< int> -
Executes
subtask.canceland waits when the operation is non-async. -
subtaskDrop(
int subtask) → void -
Executes
subtask.drop. -
toString(
) → String -
A string representation of this object.
inherited
-
waitableForHandle(
int handle) → WASIComponentWaitable? -
Resolves a subtask handle to its waitable, for
waitable.join.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited