WASIComponentVersionUnsupportedException class final
Thrown when a component uses canonical operations outside a WASI profile.
- Implemented types
Constructors
-
WASIComponentVersionUnsupportedException(Iterable<
WASIComponentVersionSupportError> errors) -
Creates an exception from version support
errors.
Properties
-
errors
→ List<
WASIComponentVersionSupportError> -
Version support errors that blocked binding.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited