WASIComponentWitFunctionBinding class final
A WIT interface function expanded from a world boundary.
Properties
- direction → WASIComponentWitWorldItemDirection
-
Whether this is an import or export boundary.
final
- function → WASIComponentWitFunction
-
WIT function boundary.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interfaceName → String
-
Local interface name that declares function.
final
- item → WASIComponentWitWorldItem
-
World item that introduced function.
final
- qualifiedName → String
-
Stable callback key, such as
filesystem.open-at.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → WASIComponentWitAdapterSignature
-
Parsed executable adapter signature.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited