WASIComponentWitLabel class final
Label declared in a WIT flags or enum type.
Constructors
- WASIComponentWitLabel({required String name, required WASIComponentWitSpan span})
-
Creates a WIT label boundary.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Label name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → WASIComponentWitSpan
-
Source span for the label name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited