WASIComponentWitVariant class final
Variant type declared directly in a WIT interface.
Constructors
-
WASIComponentWitVariant({required String name, required List<
WASIComponentWitVariantCase> cases, required WASIComponentWitSpan span}) - Creates a WIT variant declaration boundary.
Properties
-
cases
→ List<
WASIComponentWitVariantCase> -
Ordered variant cases.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Variant name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → WASIComponentWitSpan
-
Source span for the variant name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited