WASIComponentWitVariantCase class final
Case declared directly in a WIT variant.
Constructors
- WASIComponentWitVariantCase({required String name, required String? type, required WASIComponentWitSpan span})
-
Creates a WIT variant case boundary.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Case name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → WASIComponentWitSpan
-
Source span for the case name.
final
- type → String?
-
Compact payload type text, if this case carries a payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited