WASIPreview2CliHost class final
WASI 0.2 wasi:cli host imports.
Constructors
-
WASIPreview2CliHost({WASIPreview2StreamsHost? streamsHost, List<
String> args = const <String>[], Map<String, String> env = const <String, String>{}, String? initialCwd, List<int> stdinData = const <int>[], WASIPreview2InputStream? stdin, WASIPreview2OutputStream? stdout, WASIPreview2OutputStream? stderr, bool terminalStdin = false, bool terminalStdout = false, bool terminalStderr = false}) - Creates a CLI host import provider.
Properties
-
args
→ List<
String> -
Program arguments returned by
get-arguments.final -
env
→ Map<
String, String> -
Environment pairs returned by
get-environment.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Import callbacks keyed by canonical WIT adapter names.
latefinal
- initialCwd → String?
-
Initial current working directory returned by
initial-cwd.final - isStderrTerminal → bool
-
Whether stderr is configured as a terminal.
no setter
- isStdinTerminal → bool
-
Whether stdin is configured as a terminal.
no setter
- isStdoutTerminal → bool
-
Whether stdout is configured as a terminal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderrBytes → Uint8List
-
Bytes written to stderr through the returned output-stream.
no setter
- stderrHandle → int
-
Host-owned
output-streamanchor used for stderr diagnostics.latefinal - stderrStream → WASIPreview2OutputStream
-
Host stderr stream state.
no setter
- stdinData → Uint8List
-
Bytes served by
stdin.get-stdinwhen no custom stdin stream is passed.final - stdinHandle → int
-
Host-owned
input-streamanchor used for stdin diagnostics.latefinal - stdoutBytes → Uint8List
-
Bytes written to stdout through the returned output-stream.
no setter
- stdoutHandle → int
-
Host-owned
output-streamanchor used for stdout diagnostics.latefinal - stdoutStream → WASIPreview2OutputStream
-
Host stdout stream state.
no setter
- streamsHost → WASIPreview2StreamsHost
-
Shared Preview2 streams host backing stdin, stdout, and stderr handles.
final
- terminalStderrHandle → int?
-
Owned
terminal-outputhandle returned when stderr is a terminal.latefinal - terminalStdinHandle → int?
-
Owned
terminal-inputhandle returned when stdin is a terminal.latefinal - terminalStdoutHandle → int?
-
Owned
terminal-outputhandle returned when stdout is a terminal.latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited