WASIPreview2CliHost class final
WASI 0.2 wasi:cli host imports.
Constructors
-
WASIPreview2CliHost({WASIPreview2StreamsHost? streamsHost, List<
String> args = const <String>[], Map<String, String> env = const <String, String>{}, String? initialCwd, List<int> stdinData = const <int>[], WASIPreview2InputStream? stdin, WASIPreview2OutputStream? stdout, WASIPreview2OutputStream? stderr}) - Creates a CLI host import provider.
Properties
-
args
→ List<
String> -
Program arguments returned by
get-arguments.final -
env
→ Map<
String, String> -
Environment pairs returned by
get-environment.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Import callbacks keyed by canonical WIT adapter names.
latefinal
- initialCwd → String?
-
Initial current working directory returned by
initial-cwd.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderrBytes → Uint8List
-
Bytes written to stderr through the returned output-stream.
no setter
- stderrHandle → int
-
Owned
output-streamhandle returned bystderr.get-stderr.latefinal - stderrStream → WASIPreview2OutputStream
-
Host stderr stream state.
no setter
- stdinData → Uint8List
-
Bytes served by
stdin.get-stdinwhen no custom stdin stream is passed.final - stdinHandle → int
-
Owned
input-streamhandle returned bystdin.get-stdin.latefinal - stdoutBytes → Uint8List
-
Bytes written to stdout through the returned output-stream.
no setter
- stdoutHandle → int
-
Owned
output-streamhandle returned bystdout.get-stdout.latefinal - stdoutStream → WASIPreview2OutputStream
-
Host stdout stream state.
no setter
- streamsHost → WASIPreview2StreamsHost
-
Shared Preview2 streams host backing stdin, stdout, and stderr handles.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited