WASIPreview2ClocksHost class final
WASI 0.2 wasi:clocks host imports.
Constructors
- WASIPreview2ClocksHost({WASIPreview2PollHost? pollHost})
-
Creates a clocks host whose subscriptions are owned by
pollHost.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Standard
wasi:clocks@0.2.0import callbacks.latefinal - pollHost → WASIPreview2PollHost
-
Poll host used for
subscribe-instantandsubscribe-durationhandles.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited