WASIPreview2FilesystemHost class base
WASI 0.2 wasi:filesystem host imports.
- Implementers
Constructors
-
WASIPreview2FilesystemHost({Map<
String, WASIPreview2FilesystemDirectory> preopens = const <String, WASIPreview2FilesystemDirectory>{}, WASIComponentResourceTable? table, WASIPreview2StreamsHost? streamsHost}) - Creates a filesystem host with preopened guest directories.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Import callbacks keyed by canonical WIT adapter names.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamsHost → WASIPreview2StreamsHost
-
Streams host used by file read/write stream operations.
final
- table → WASIComponentResourceTable
-
Component resource table that owns filesystem and stream handles.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited