WASIPreview2FilesystemMetadata class final
Metadata returned by WASI 0.2 filesystem stat operations.
Constructors
Properties
- accessTimeNanos → BigInt?
-
Access timestamp in nanoseconds since the Unix epoch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkCount → BigInt?
-
Number of hard links, or null when the backing store cannot report it.
final
- modificationTimeNanos → BigInt?
-
Modification timestamp in nanoseconds since the Unix epoch.
final
- objectIdentity → String?
-
Host-specific object identity used for
descriptor.is-same-object.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → BigInt?
-
Current byte size, or null to use the descriptor's existing size provider.
final
- statusChangeTimeNanos → BigInt?
-
Status-change timestamp in nanoseconds since the Unix epoch.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited