WASIPreview2HttpResponseOutparam class final
Preview2 response outparam resource.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
informationalResponses
→ List<
WASIPreview2HttpInformationalResponse> -
Informational responses sent before the final response.
no setter
-
response
→ WASIPreview2HttpResult<
WASIPreview2HttpOutgoingResponse> ? -
Stored response, when set.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendInformational(
int status, WASIPreview2HttpFields headers) → WASIPreview2HttpResult< void> - Sends an informational response before the final response.
-
set(
WASIPreview2HttpResult< WASIPreview2HttpOutgoingResponse> response) → bool - Sets the response once.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited