WASIPreview2IoError class final
Host-owned WASI 0.2 wasi:io/error.error value.
Constructors
- WASIPreview2IoError(String debugString)
-
Creates an I/O error with a human-readable debug string.
const
Properties
- debugString → String
-
Human-readable diagnostic text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited