WASIPreview2Pollable class final
Readiness source for WASI 0.2 wasi:io/poll.pollable.
Constructors
-
WASIPreview2Pollable({required bool isReady(), required Future<
void> waitReady()}) - Creates a pollable backed by readiness and wait callbacks.
Properties
Methods
-
block(
) → Future< void> - Waits until this pollable becomes ready.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited