WASIPreview2UnsupportedHttpBackend class final
Backend that rejects all outgoing requests.
- Implemented types
Constructors
- WASIPreview2UnsupportedHttpBackend()
-
Creates an unsupported HTTP backend.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
WASIPreview2HttpOutgoingRequest request, WASIPreview2HttpRequestOptions? options) → WASIPreview2HttpResult< WASIPreview2HttpFutureIncomingResponse> -
Starts an outgoing HTTP request.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited