WASIPreview3CliHost class final
WASI 0.3 wasi:cli host imports.
Constructors
-
WASIPreview3CliHost({List<
String> args = const <String>[], Map<String, String> env = const <String, String>{}, String? initialCwd, List<int> stdinData = const <int>[], WASIPreview3CliOutputHandler? stdout, WASIPreview3CliOutputHandler? stderr}) - Creates a CLI host import provider.
Properties
-
args
→ List<
String> -
Program arguments returned by
get-arguments.final -
env
→ Map<
String, String> -
Environment pairs returned by
get-environment.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Import callbacks keyed by canonical WIT adapter names.
latefinal
- initialCwd → String?
-
Initial current working directory returned by
get-initial-cwd.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderrBytes → Uint8List
-
Bytes written to stderr when no custom sink consumes them first.
no setter
- stdinData → Uint8List
-
Bytes served by
stdin.read-via-stream.final - stdoutBytes → Uint8List
-
Bytes written to stdout when no custom sink consumes them first.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited