WASIPreview3HttpHost class base
WASI 0.3 wasi:http host imports.
- Implementers
Constructors
- WASIPreview3HttpHost({WASIComponentResourceTable? table, WASIPreview3HttpBackend? clientBackend, WASIPreview3HttpBackend? handlerBackend, BigInt? maximumRequestTimeoutNanos})
- Creates a Preview3 HTTP host.
Properties
- clientBackend → WASIPreview3HttpBackend
-
Backend for
wasi:http/client.send.final - handlerBackend → WASIPreview3HttpBackend
-
Backend for the handler imported by the middleware world.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Stable Preview3 HTTP import callbacks.
latefinal
- maximumRequestTimeoutNanos → BigInt?
-
Largest supported request timeout in nanoseconds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- table → WASIComponentResourceTable
-
Shared component resource table.
final
Methods
-
close(
{bool force = false}) → void - Releases resources created and owned by this host.
-
insertFields(
WASIPreview3HttpFields fields) → int - Inserts an owned fields resource.
-
insertRequest(
WASIPreview3HttpRequest request) → int - Inserts an owned request for delivery to a component handler.
-
insertResponse(
WASIPreview3HttpResponse response) → int - Inserts an owned response.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
takeResponse(
int handle, {bool retainResourceScope = false}) → WASIPreview3HttpResponse - Takes an owned response returned by a component handler.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited