WASIPreview3HttpRequestOptions class final
Preview3 HTTP request transport options.
Constructors
- WASIPreview3HttpRequestOptions({BigInt? connectTimeout, BigInt? firstByteTimeout, BigInt? betweenBytesTimeout, bool mutable = true})
- Creates mutable request options.
Properties
- betweenBytesTimeout ↔ BigInt?
-
Timeout between response chunks in nanoseconds.
getter/setter pair
- connectTimeout ↔ BigInt?
-
Connect timeout in nanoseconds.
getter/setter pair
- firstByteTimeout ↔ BigInt?
-
Timeout to the first response byte in nanoseconds.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mutable → bool
-
Whether setters may mutate this resource.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
immutableClone(
) → WASIPreview3HttpRequestOptions - Returns an immutable copy for attachment to a request.
-
mutableClone(
) → WASIPreview3HttpRequestOptions - Returns a mutable deep copy.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited