WASIPreview3HttpResult<T> class
final
Result returned by Preview3 HTTP handlers and transports.
Constructors
- WASIPreview3HttpResult.error(String errorCode)
-
Creates an HTTP
error-coderesult.const - WASIPreview3HttpResult.ok(T value)
-
Creates a successful result.
const
Properties
- errorCode → String?
-
Stable
wasi:http/types.error-codecase label.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isOk → bool
-
Whether this result is successful.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
Successful value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited