WASIPreview3RandomHost class final
WASI 0.3 wasi:random host imports.
Constructors
- WASIPreview3RandomHost({Random? secureRandom, Random? insecureRandom})
- Creates a random host import provider.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, WASIComponentWitAdapterCallback> -
Import callbacks keyed by canonical WIT adapter names.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited