Backend used by WASIPreview3SocketsHost for network I/O.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startTcpBind(
WASIPreview3IpSocketAddress localAddress, {required BigInt backlog}) → WASIPreview3SocketOperation< WASIPreview3TcpBinding> - Reserves a TCP endpoint.
-
startTcpConnect(
{required WASIPreview3IpSocketAddress remoteAddress, WASIPreview3IpSocketAddress? localAddress, WASIPreview3TcpBinding? binding}) → WASIPreview3SocketOperation< WASIPreview3TcpConnection> -
Connects a TCP endpoint, consuming
bindingwhen one is supplied. -
startTcpListen(
{required WASIPreview3IpSocketAddress localAddress, required BigInt backlog, WASIPreview3TcpBinding? binding}) → WASIPreview3SocketOperation< WASIPreview3TcpListener> -
Starts a TCP listener, consuming
bindingwhen one is supplied. -
startUdpBind(
WASIPreview3IpSocketAddress localAddress) → WASIPreview3SocketOperation< WASIPreview3UdpBinding> - Binds a UDP endpoint.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited