Listening TCP socket returned by a sockets backend.
Properties
- canAccept → bool
-
Whether accept can make progress without waiting.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- localAddress → WASIPreview3IpSocketAddress
-
Bound local address.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept(
) → WASIPreview3SocketResult< WASIPreview3TcpConnection> - Accepts one queued connection.
-
close(
) → void - Closes the listener.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitAccept(
) → Future< void> - Waits until accept may make progress.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited