Bound UDP socket returned by a sockets backend.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- localAddress → WASIPreview3IpSocketAddress
-
Bound local address.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the binding.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receive(
) → Future< WASIPreview3SocketResult< WASIPreview3IncomingDatagram> > - Receives one datagram.
-
send(
Uint8List data, WASIPreview3IpSocketAddress remoteAddress) → Future< WASIPreview3SocketResult< void> > - Sends one datagram.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited