WasmComponent class final
Properties
-
aliases
→ List<
WasmComponentAlias> -
final
-
canonicalDefinitions
→ List<
WasmComponentCanonicalDefinition> -
final
-
componentFunctionIndexTypeContexts
→ List<
WasmComponentFunctionTypeContext?> -
Component function types paired with the type scope that defines their
parameter and result indexes.
no setter
-
componentFunctionIndexTypes
→ List<
WasmComponentFunctionType?> -
Locally materialized component function index types in definition order.
no setter
-
components
→ List<
WasmComponent> -
final
-
componentTypeIndexDefinitions
→ List<
WasmComponentTypeDefinition> -
Locally materialized component type index definitions in definition order.
no setter
-
componentValueIndexTypes
→ List<
WasmComponentValueType?> -
Locally materialized component value index types in definition order.
no setter
-
coreInstances
→ List<
WasmComponentCoreInstance> -
final
-
coreModules
→ List<
WasmModule> -
final
-
coreTypes
→ List<
WasmComponentCoreType> -
final
-
definitionEvents
→ List<
WasmComponentDefinitionEvent> -
Decoded definition events in component index-space order.
no setter
-
exports
→ List<
WasmComponentExport> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ List<
WasmComponentImport> -
final
-
instances
→ List<
WasmComponentInstance> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
WasmComponentSection> -
final
-
starts
→ List<
WasmComponentStart> -
final
-
typeDefinitions
→ List<
WasmComponentTypeDefinition> -
final
-
valueDefinitions
→ List<
WasmComponentValueDefinition> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → List< WasmComponentValidationError>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Uint8List bytes, {WasmFeatureSet features = const WasmFeatureSet(componentModel: true)}) → WasmComponent -
hasComponentPreamble(
List< int> bytes) → bool