WasmComponentImportRequirement class final
Component-level import requirement decoded from section 0x04.
Constructors
- WasmComponentImportRequirement({required String componentImportName, required String moduleName, required String fieldName, required WasmComponentImportKind kind})
-
const
Properties
- componentImportName → String
-
final
- fieldName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WasmComponentImportKind
-
final
- moduleName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited