WasmComponentInstance class final
Constructors
-
WasmComponentInstance.inlineExports({required List<
WasmComponentInlineExport> exports}) -
const
-
WasmComponentInstance.instantiate({required int? componentIndex, required List<
WasmComponentInstantiationArgument> arguments}) -
const
Properties
-
arguments
→ List<
WasmComponentInstantiationArgument> -
final
- componentIndex → int?
-
final
-
exports
→ List<
WasmComponentInlineExport> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WasmComponentInstanceKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited