WasmComponentTypeDefinition class final
Constructors
- WasmComponentTypeDefinition({required WasmComponentTypeKind kind, WasmComponentDefinedValueType? definedValue, WasmComponentFunctionType? function, WasmComponentComponentType? component, WasmComponentInstanceType? instance, WasmComponentResourceType? resource})
-
const
Properties
- component → WasmComponentComponentType?
-
final
- definedValue → WasmComponentDefinedValueType?
-
final
- function → WasmComponentFunctionType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → WasmComponentInstanceType?
-
final
- kind → WasmComponentTypeKind
-
final
- resource → WasmComponentResourceType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited