WasmFeatureSet class final
Constructors
-
WasmFeatureSet({bool simd = false, bool threads = false, bool exceptionHandling = false, bool gc = false, bool componentModel = false, Set<
String> additionalEnabled = const <String>{}, Set<String> additionalDisabled = const <String>{}}) -
const
-
WasmFeatureSet.layeredDefaults({WasmFeatureProfile profile = WasmFeatureProfile.stable, Set<
String> additionalEnabled = const <String>{}, Set<String> additionalDisabled = const <String>{}}) -
factory
Properties
-
additionalDisabled
→ Set<
String> -
Feature names forcibly disabled after defaults + additions are applied.
final
-
additionalEnabled
→ Set<
String> -
Forward-compatible extension point for proposals not yet modeled as fields.
final
- componentModel → bool
-
final
-
enabledFeatures
→ Set<
String> -
no setter
- exceptionHandling → bool
-
final
- gc → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simd → bool
-
final
- threads → bool
-
final
Methods
-
copyWith(
{bool? simd, bool? threads, bool? exceptionHandling, bool? gc, bool? componentModel, Set< String> ? additionalEnabled, Set<String> ? additionalDisabled}) → WasmFeatureSet -
isEnabled(
String featureName) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited